buildlet: increase timeout period for client

The a1.metal instances take about four minutes to become available
before beginning to boot the Windows ARM64 VM. This means we need
somewhere between five and ten minutes before we can first connect to
the buildlet.

It's possible that other instances are faster to boot, but this is
currently the most economical choice.

For golang/go#42604

Change-Id: Ib76944307c9ad28fd1adca0dc54f3fbeaabfffa0
Reviewed-on: https://go-review.googlesource.com/c/build/+/322654
Trust: Alexander Rakoczy <alex@golang.org>
Run-TryBot: Alexander Rakoczy <alex@golang.org>
TryBot-Result: Go Bot <gobot@golang.org>
Reviewed-by: Carlos Amedee <carlos@golang.org>
diff --git a/buildlet/buildlet.go b/buildlet/buildlet.go
index 9a58a90..1696303 100644
--- a/buildlet/buildlet.go
+++ b/buildlet/buildlet.go
@@ -82,9 +82,9 @@
 // it can connect with the endpoint before returning. The buildletURL is in the form of:
 // "https://<ip>". The ipPort field is in the form of "<ip>:<port>". The function
 // will attempt to connect to the buildlet for the lesser of: the default timeout period
 // (5 minutes) or the timeout set in the passed in context.
 func buildletClient(ctx context.Context, buildletURL, ipPort string, opts *VMOpts) (*Client, error) {
-	ctx, cancel := context.WithTimeout(ctx, 5*time.Minute)
+	ctx, cancel := context.WithTimeout(ctx, 10*time.Minute)
 	defer cancel()
 	try := 0
 	for !opts.SkipEndpointVerification {
@@ -82,9 +82,9 @@
 // "https://<ip>". The ipPort field is in the form of "<ip>:<port>". The function
 // will attempt to connect to the buildlet for the lesser of: the default timeout period
-// (5 minutes) or the timeout set in the passed in context.
+// (10 minutes) or the timeout set in the passed in context.
 func buildletClient(ctx context.Context, buildletURL, ipPort string, opts *VMOpts) (*Client, error) {